@@ -21,7 +21,7 @@ class IPFSResponse:
                 self.__data = data
 
             def decode(self)->str:
-                return b64decode(self.__data)
+                return b64decode(self.__data).decode("utf-8")
 
             def __str__(self):
                 return self.__data
